<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <link rel="stylesheet" href="{{asset('assets/css/style.css')}}">
    <link rel="stylesheet" href="{{asset('assets/css/bootstrap.min.css')}}">
    <link rel="stylesheet" href="{{asset('assets/css/soft-ui-dashboard.css')}}">
    <link rel="stylesheet" href="{{asset('assets/css/soft-ui-dashboard.min.css')}}">
    <link rel="stylesheet" href="{{asset('assets/css/soft-ui-dashboard.css.map')}}">
    <link rel="stylesheet" href="{{asset('assets/css/nucleo-svg.css')}}">
    <title>Invoice</title>
    <style>
        /* Basic reset */
        body,
        html {
            margin: 0;
            padding: 0;
            font-family: Arial, sans-serif;
            background-color: rgb(253, 253, 253) !important;
        }

        /* Thermal printer page size */
        .invoice-wrapper {
            width: 80mm;
            /* Thermal printer width */
            margin: 0 auto;
            padding: 5mm;
            font-size: 12px;
        }

        /* Centering content */
        .header {
            text-align: center;
        }

        .invoice-logo img {
            width: 70%;
            /* Adjust logo to fit thermal print */
            max-width: 100%;
            object-fit: contain;
        }

        .invoice-title {
            font-size: 14px;
            font-weight: bold;
            margin-top: 5mm;
        }

        /* Invoice From / To Table */
        .info-section {
            margin-top: 10mm;
        }

        .info-section table {
            width: 100%;
            border: none;
            margin-top: 5mm;
        }

        .info-section td {
            padding: 2mm 0;
        }

        .info-section h4 {
            font-size: 14px;
            margin-bottom: 2mm;
        }

        .info-section p {
            font-size: 12px;
            margin: 2px 0;
        }

        /* Table styles for item details */
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 5mm;
            table-layout: fixed;
        }

        table th,
        table td {
            font-size: 12px;
            padding: 2mm;
            text-align: left;
        }

        table th {
            background-color: #f2f2f2;
        }

        table td {
            text-align: right;
        }

        /* Total Section */
        .total-section td {
            font-weight: bold;
        }

        /* Footer Note */
        .footer-note {
            font-size: 8px;
            color: #888;
            margin-top: 10mm;
            text-align: center;
        }

        /* Hide buttons during print */
        @media print {
            .invoice-btn-section {
                display: none;
            }
        }

        /* Print settings for thermal printer */
        @media print {
            body {
                margin: 0;
                padding: 0;
                font-size: 12px;
            }

            .invoice-wrapper {
                width: 80mm;
                page-break-before: always;
            }

            /* Make sure text is properly aligned for printing */
            .info-section {
                margin-top: 10mm;
            }

            .info-section table {
                width: 100%;
            }

            .info-section td {
                width: 50%;
                vertical-align: top;
            }

        }

        .form-select {
            margin-bottom: 1rem !important;
        }
    </style>
</head>

<body>

    <div class="invoice-wrapper" id="invoice_wrapper">
        <!-- Header with logo and invoice title -->
        <div class="header">
            <div class="invoice-logo">
                <img src="{{ getFileUrl($settings->logo ? $settings->logo : 'storage/logo/logo_invoice.png') }}"
                    alt="logo">
            </div>
            <div class="invoice-title">Invoice #{{ $addedInvoice->invoice_id ?? '' }}</div>
            <div class="invoice-title">Invoice Date:
                {{ $addedInvoice->invoice_date ? \Carbon\Carbon::parse($addedInvoice->invoice_date)->format('d-m-Y') : '' }}
            </div>
        </div>

        <!-- Sender/Receiver Information in Table format -->
        <div class="info-section">
            <table style="width: 100%; border: none;">
                <tr>
                    <td style="text-align: left; vertical-align: top; padding-right: 10px;">
                        <h4>Invoice From:</h4>
                        <p>{{ $settings->company_name ?? '' }}</p>
                        <p>{{ $settings->address ?? '' }}</p>
                        <p>{{ $settings->email ?? '' }}</p>
                        <p>(+91) {{ $settings->phone ?? '' }}</p>
                    </td>
                    <td style="text-align: left; vertical-align: top;">
                        <h4>Invoice To:</h4>
                        <p>{{ $addedInvoice->client->user->name ?? '' }}</p>
                        <p>(+91) {{ $addedInvoice->client->user->phone ?? '' }}</p>
                    </td>
                </tr>
            </table>
        </div>


        <!-- Invoice Details Table -->
        <table>
            <thead>
                <tr>
                    <th>No.</th>
                    <th>Item Description</th>
                    <th>Price</th>
                    <th>Quantity</th>
                    <th>Amount</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($addedInvoice->invoiceItems as $index => $data)
                    <tr>
                        <td>{{ $index + 1 }}</td>
                        <td>{{ $data->product_name ?? '' }}</td>
                        <td>{{ $data->price ?? '' }}</td>
                        <td>{{ $data->quantity ?? '' }}</td>
                        <td>{{ $data->total ?? '' }}</td>
                    </tr>
                @endforeach
                <tr>
                    <td colspan="4" style="text-align: right;">SubTotal</td>
                    <td>{{ $addedInvoice->amount ?? '0' }}</td>
                </tr>
                <tr>
                    <td colspan="4" style="text-align: right;">Tax</td>
                    <td> @php
                        $totalTax = 0;
                        foreach ($addedInvoice->invoiceItems as $item) {
                            if ($item->invoiceItemTaxes) {
                                foreach ($item->invoiceItemTaxes as $tax) {
                                    $totalTax += ($item->total * $tax->tax) / 100;
                                }
                            }
                        }
                    @endphp
                        ₹{{ number_format($totalTax, 2) }}
                    </td>
                </tr>
                <tr>
                    <td colspan="4" style="text-align: right;">Discount</td>
                    <td> @php
                        $totalDiscount = 0;
                        $total = $addedInvoice->amount + $totalTax;
                        if ($addedInvoice->discount_type == 1) {
                            $totalDiscount = $addedInvoice->discount;
                        } elseif ($addedInvoice->discount_type == 2) {
                            $discountAmount = ($total * $addedInvoice->discount)
                                / 100;
                            $totalDiscount = $discountAmount;
                        } else {
                            $totalDiscount = 0;
                        }                                            
                    @endphp
                        ₹ {{number_format($totalDiscount ?? 0, 2)}}</td>
                    </td>
                </tr>
                <tr>
                    <td colspan="4" style="text-align: right;">Grand Total</td>
                    <td><strong> {{number_format(floor($total - $totalDiscount) ?? 0, 2)}}</strong></td>
                </tr>
                <tr>
                    <td colspan="4" style="text-align: right;">Total Purchased Product Qty</td>
                    @php
                        $sumQty = 0;
                        foreach ($addedInvoice->invoiceItems as $item) {
                            $sumQty += $item->quantity;
                        }                      
                    @endphp
                    <td><strong> {{ $sumQty ?? 0}}</strong></td>
                </tr>
            </tbody>
        </table>

        <!-- Footer Note -->
        <!-- <div class="footer-note">
        <p>Thank you for your business! We appreciate your trust and look forward to serving you again soon.</p>
    </div> -->

        <!-- Print/Download Buttons (visible only in normal view, not in print) -->
        <div class="invoice-btn-section">
            <div class="d-flex gap-2 ">
                <select name="paper_size" id="paper_size" class="form-select">
                    <option value="">Select Standard paper size</option>
                    @foreach ($paper as $item)
                        <option value="{{$item->id}}">{{$item->name}}</option>
                    @endforeach
                </select>
            </div>
            <div class="d-flex gap-2">
                <a href="javascript:window.print()" class="btn">
                    <i class="fa fa-print"></i> Print Invoice
                </a>
                <a id="invoice_download_btn" class="btn">
                    <i class="fa fa-download"></i> Download Invoice
                </a>
            </div>
            <div class="d-flex gap-2">
                @if ($settings->whatsapp_config == 'A')
                    <a href="#" id="send_invoice" class="btn">
                        <i class="fa-brands fa-whatsapp"></i>Send Invoice
                    </a>
                @endif
                <a href='{{route('invoice-index')}}' id="cancel-btn" class="btn">
                    <i class="fa fa-arrow-left"></i> Back
                </a>
            </div>

        </div>
    </div>

    <!-- JS Scripts for Downloading as PDF -->
    <script src="https://code.jquery.com/jquery-3.7.1.min.js"></script>
    <script src="{{asset('assets/js/jspdf.min.js')}}"></script>
    <script src="{{asset('assets/js/html2canvas.js')}}"></script>

    <script>
        $(function () {
            $(document).on('click', '#invoice_download_btn', function () {

                $(".invoice-btn-section").hide();

                var content = $("#invoice_wrapper");

                // Step 1: Apply temporary scale-down before capturing
                content.css({
                    transform: 'scale(0.95)',
                    transformOrigin: 'top left'
                });

                // Allow DOM to update before canvas capture
                setTimeout(function () {

                    var contentElement = content[0];

                    var contentWidth = contentElement.offsetWidth;
                    var contentHeight = contentElement.offsetHeight;

                    var pdfWidth = 80; // Thermal printer width in mm
                    var pdfHeight = (contentHeight * pdfWidth) / contentWidth;

                    html2canvas(contentElement, {
                        allowTaint: true,
                        scale: 2,
                        useCORS: true
                    }).then(function (canvas) {

                        var imgData = canvas.toDataURL("image/jpeg", 1.0);
                        var pdf = new jsPDF('p', 'mm', [pdfWidth, pdfHeight]);

                        pdf.addImage(imgData, 'JPEG', 0, 0, pdfWidth, pdfHeight);
                        pdf.save("{{$addedInvoice->invoice_id}}.pdf");

                        // Step 3: Reset the scale after PDF generation
                        content.css({
                            transform: '',
                            transformOrigin: ''
                        });

                        $(".invoice-btn-section").show();
                    });

                }, 300); // slight delay to ensure transform is applied

            });
        });
    </script>


    <script>
        $(function () {
            $(document).on('click', '#send_invoice', function () {
                $(".invoice-btn-section").hide();

                var content = $("#invoice_wrapper")[0];
                var contentWidth = content.offsetWidth;
                var contentHeight = content.offsetHeight;
                var pdfWidth = 80;
                var pdfHeight = (contentHeight * pdfWidth) / contentWidth;

                html2canvas(content, {
                    allowTaint: true,
                    scale: 2,
                    useCORS: true
                }).then(function (canvas) {
                    var imgData = canvas.toDataURL("image/jpeg", 1.0);
                    var pdf = new jsPDF('p', 'mm', [pdfWidth, pdfHeight]);
                    pdf.addImage(imgData, 'JPEG', 0, 0, pdfWidth, pdfHeight);

                    var pdfBlob = pdf.output('blob');
                    var formData = new FormData();
                    formData.append("invoice_pdf", pdfBlob, "invoice_{{$addedInvoice->invoice_id}}.pdf");
                    formData.append("_token", "{{ csrf_token() }}");
                    formData.append("invoice_id", "{{$addedInvoice->invoice_id}}");
                    formData.append("invoice_amnt", "{{$addedInvoice->final_amount}}");
                    formData.append("phone_number", "{{ $addedInvoice->client->user->phone ?? '' }}");
                    // Send the PDF to the backend
                    $.ajax({
                        url: "{{ route('send.invoice') }}",
                        type: "POST",
                        data: formData,
                        processData: false,
                        contentType: false,
                        success: function (response) {
                            if (response) {
                                Swal.fire({
                                    title: "Success!",
                                    text: "Message sent successfully!",
                                    icon: "success",
                                    confirmButtonText: "OK"
                                });

                            }
                            else {
                                Swal.fire({
                                    title: "Error!",
                                    text: "Error sending invoice!",
                                    icon: "error",
                                    confirmButtonText: "OK"
                                });

                            }
                            $(".invoice-btn-section").show();
                        },
                        error: function () {
                            Swal.fire({
                                title: "Error!",
                                text: "Something went wrong while processing the request.",
                                icon: "error",
                                confirmButtonText: "OK"
                            });
                            $(".invoice-btn-section").show();
                        }
                    });
                });
            });
        });       
    </script>
    <script>
        $(function () {
            $(document).on('change', '#paper_size', function () {
                const paperId = $('#paper_size').val();
                const invoiceId = "{{ $addedInvoice->id }}";

                window.location.href = "{{ route('pdf', ['id' => 'INVOICE_ID_PLACEHOLDER']) }}".replace('INVOICE_ID_PLACEHOLDER', invoiceId) + "?paperId=" + paperId;
            });
        });
    </script>
</body>

</html>